netapp_ontap.models.cloud_storage_tier API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cloud_storage_tier`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class CloudStorageTierSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CloudStorageTier object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cloud_store GET`

    The cloud_store field of the cloud_storage_tier.

  `used GET`

    Capacity used in bytes in the cloud store by this aggregate. This is a cached value calculated every 5 minutes.